"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
class Requests {
    static async postHubAccount(host, request) {
        const url = `${host}/participants/Hub/accounts`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postSettlementModel(host, request) {
        const url = `${host}/settlementModels`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postHubEndpoints(host, request) {
        const url = `${host}/participants/Hub/endpoints`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postOracles(host, request) {
        const url = `${host}/oracles`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
                Date: (new Date()).toISOString()
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postParticipants(host, request) {
        const url = `${host}/participants`;
        const options = {
            method: 'post',
            headers: {
                'Content-Type': 'application/json',
            },
            url,
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postParticipantsPositionAndLimits(host, request) {
        const url = `${host}/participants/${request.participantId}/initialPositionAndLimits`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async getParticipant(host, participantId) {
        const url = `${host}/participants/${participantId}`;
        const options = {
            method: 'get',
            url,
        };
        return this.executeRequest(options);
    }
    static async postAccount(host, request) {
        const url = `${host}/participants/${request.participantId}/accounts/${request.accountId}`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postEndpoint(host, request) {
        const url = `${host}/participants/${request.participantId}/endpoints`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postSimulatorParty(host, request) {
        const url = `${host}/repository/parties`;
        const options = {
            method: 'post',
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postALSParticipant(host, request) {
        const url = `${host}/participants/${request.idType}/${request.idValueOrSubType}` + (request.idValue ? `/${request.idValue}` : '');
        const options = {
            method: 'post',
            url,
            headers: {
                'Accept': 'application/vnd.interoperability.participants+json;version=1',
                'Content-Type': 'application/vnd.interoperability.participants+json;version=1.0',
                Date: (new Date()).toISOString(),
                ...request.headers
            },
            data: {
                ...request.body
            }
        };
        console.log('options are', options);
        return this.executeRequest(options);
    }
    static async executeRequest(options) {
        try {
            const result = await axios_1.default(options);
            return result;
        }
        catch (err) {
            if (err.response) {
                console.log(`executeRequest failed with status: ${err.response.status}`);
                console.log(err.response.data);
                // TODO: better error handling
                throw new Error(`Status: ${err.response.status} Message: ${JSON.stringify(err.response.data)}`);
            }
            console.log('Generic Error', err.message);
            throw err;
        }
    }
}
exports.default = Requests;
//# sourceMappingURL=requests.js.map